==> gd32f1-0.2.1.crate: gd32f1-0.2.1/src/gd32f130/dma/ch2cnt.rs <==
#[doc = "Register `CH2CNT` reader"]
pub struct R(crate::R<CH2CNT_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<CH2CNT_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::convert::From<crate::R<CH2CNT_SPEC>> for R {
    fn from(reader: crate::R<CH2CNT_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `CH2CNT` writer"]
pub struct W(crate::W<CH2CNT_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<CH2CNT_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl core::convert::From<crate::W<CH2CNT_SPEC>> for W {
    fn from(writer: crate::W<CH2CNT_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `CNT` reader - Transfer counter"]
pub struct CNT_R(crate::FieldReader<u16, u16>);
impl CNT_R {
    pub(crate) fn new(bits: u16) -> Self {
        CNT_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for CNT_R {
    type Target = crate::FieldReader<u16, u16>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `CNT` writer - Transfer counter"]
pub struct CNT_W<'a> {
    w: &'a mut W,
}
impl<'a> CNT_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bits(self, value: u16) -> &'a mut W {
        self.w.bits = (self.w.bits & !0xffff) | (value as u32 & 0xffff);
        self.w
    }
}
impl R {
    #[doc = "Bits 0:15 - Transfer counter"]
    #[inline(always)]
    pub fn cnt(&self) -> CNT_R {
        CNT_R::new((self.bits & 0xffff) as u16)
    }
}
impl W {
    #[doc = "Bits 0:15 - Transfer counter"]
    #[inline(always)]
    pub fn cnt(&mut self) -> CNT_W {
        CNT_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "DMA channel 2 counter register\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [ch2cnt](index.html) module"]
pub struct CH2CNT_SPEC;
impl crate::RegisterSpec for CH2CNT_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [ch2cnt::R](R) reader structure"]
impl crate::Readable for CH2CNT_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [ch2cnt::W](W) writer structure"]
impl crate::Writable for CH2CNT_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets CH2CNT to value 0"]
impl crate::Resettable for CH2CNT_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}

==> gd32f1-0.5.0.crate: gd32f1-0.5.0/src/gd32f130/dma/ch2cnt.rs <==
#[doc = "Register `CH2CNT` reader"]
pub struct R(crate::R<CH2CNT_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<CH2CNT_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<CH2CNT_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<CH2CNT_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `CH2CNT` writer"]
pub struct W(crate::W<CH2CNT_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<CH2CNT_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<CH2CNT_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<CH2CNT_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `CNT` reader - Transfer counter"]
pub struct CNT_R(crate::FieldReader<u16, u16>);
impl CNT_R {
    pub(crate) fn new(bits: u16) -> Self {
        CNT_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for CNT_R {
    type Target = crate::FieldReader<u16, u16>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `CNT` writer - Transfer counter"]
pub struct CNT_W<'a> {
    w: &'a mut W,
}
impl<'a> CNT_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bits(self, value: u16) -> &'a mut W {
        self.w.bits = (self.w.bits & !0xffff) | (value as u32 & 0xffff);
        self.w
    }
}
impl R {
    #[doc = "Bits 0:15 - Transfer counter"]
    #[inline(always)]
    pub fn cnt(&self) -> CNT_R {
        CNT_R::new((self.bits & 0xffff) as u16)
    }
}
impl W {
    #[doc = "Bits 0:15 - Transfer counter"]
    #[inline(always)]
    pub fn cnt(&mut self) -> CNT_W {
        CNT_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "DMA channel 2 counter register\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [ch2cnt](index.html) module"]
pub struct CH2CNT_SPEC;
impl crate::RegisterSpec for CH2CNT_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [ch2cnt::R](R) reader structure"]
impl crate::Readable for CH2CNT_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [ch2cnt::W](W) writer structure"]
impl crate::Writable for CH2CNT_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets CH2CNT to value 0"]
impl crate::Resettable for CH2CNT_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}
